@@ -65,6 +65,7 @@ OC.L10N.register(
     "name@example.org" : "nimi@toredomeen.ee",
     "Please enter an email of the format name@example.com" : "Palun sisesta e-posti aadress nimi@toredomeen.ee vormingus",
     "Password" : "Salasõna",
+    "Enable mark as important classification" : "Kasuta märget olulise klassifikaatorina",
     "Manual" : "Käsitsi",
     "IMAP Settings" : "IMAP-i seadistused",
     "IMAP Host" : "IMAP-i server",
@@ -97,6 +98,7 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automaatsed vastused saabunud kirjadele. Kui keegi saadab sulle enam  kui ühe kirja, siis saab ta automaatse vastuse kord 4 päeva jooksul.",
     "The autoresponder uses Sieve, a scripting language supported by many email providers. If you're unsure whether yours does, check with your provider. If Sieve is available, click the button to go to the settings and enable it." : "Automaatvastaja on loodud Sieve skriptimiskeeles ja tavaliselt on selline võimalus toetatud paljude e-posti teenuste puhul. Kui sa pole enda omas kindel, siis palun küsi neilt üle. Kui Sieve on kasutatav, siis klõpsi järgnevat nuppu ja võta ta seadistustest kasutusele.",
     "Go to Sieve settings" : "Ava Sieve seadistused",
+    "Classification settings" : "Klassifitseerimise seadistused",
     "Filters" : "Filtrid",
     "Quick actions" : "Kiirtoimingud",
     "Sieve script editor" : "Sieve skriptikoostaja",
@@ -115,55 +117,49 @@ OC.L10N.register(
     "Cancel" : "Katkesta",
     "Search the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
     "Activate" : "Lülita sisse",
-    "Determine importance using machine learning" : "Määra olulisus masinõppe abil",
     "Remind about messages that require a reply but received none" : "Tuleta mulle meelde kirju, mis eeldavad vastust, kui pole seda veel saanud",
     "Highlight external addresses" : "Tõsta välised aadressid esile",
     "Could not update preference" : "Eelistust polnud võimalik muuta",
     "Mail settings" : "E-kirjade seadistused",
     "General" : "Üldine",
+    "Set as default mail app" : "Määra vaikimisi e-postirakenduseks",
     "Add mail account" : "Lisa e-posti  konto",
-    "Settings for:" : "Seadistused:",
     "Appearance" : "Välimus",
+    "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
+    "When off, only the selected message will be shown" : "Kui eelistus pole kasutusel, siis näidatakse vaid valitud kirja",
     "Layout" : "Välimus",
-    "List" : "Nimekiri",
     "Vertical split" : "Püstjoones jagamine",
     "Horizontal split" : "Rõhtjoones jagamine",
+    "List" : "Nimekiri",
     "Sorting" : "Järjestus",
     "Newest first" : "Uuemad eespool",
     "Oldest first" : "Vanemad eespool",
-    "Message view mode" : "Kirjade vaate liik",
-    "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
-    "When off, only the selected message will be shown" : "Kui eelistus pole kasutusel, siis näidatakse vaid valitud kirja",
+    "Avatars from Gravatar and favicons" : "Favikonid ja tunnuspildid teenusest Gravatar",
     "Reply position" : "Vastuse asukoht",
     "Top" : "Üleval",
     "Bottom" : "All",
-    "Search in body" : "Otsi kirja sisust",
-    "Gravatar settings" : "Gravatari seadistused",
-    "Avatars from Gravatar and favicons" : "Favikonid ja tunnuspildid teenusest Gravatar",
-    "Mailto" : "Mailto",
-    "Set as default mail app" : "Määra vaikimisi e-postirakenduseks",
-    "Register" : "Registreeru",
     "Text blocks" : "Tekstiplokid",
     "Reusable pieces of text that can be inserted in messages" : "Teksti kasutatavad osad, misa saad kirjadesse lisada",
     "New text block" : "Uus tekstiplokk",
     "Shared with me" : "Jagatud minuga",
-    "Privacy and security" : "Privaatsus ja turvalisus",
+    "Privacy" : "Privaatsus",
     "Data collection" : "Andmete kogumine",
-    "Allow the app to collect and process data locally to adapt to your preferences." : "Luba rakendusel kohalikus seadmes andmeid koguda ja töödelda ning lasta kohanduda sinu eelistustega.",
+    "Allow the app to collect and process data locally to adapt to your preferences" : "Luba rakendusel kohalikus seadmes andmeid koguda ja töödelda ning lasta kohanduda sinu eelistustega",
     "Always show images from" : "Alati näita pilte saatjalt",
     "Security" : "Turvalisus",
-    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Selle valikuga tõstetakse välised e-posti aadressid esile, hallatakse sinu jaoks serveri sisemisi aadresse ja domeene. Nii tagatakse, et sinu poolt kinnitatud kontaktid jäävad esiletõstmata.",
+    "Manage your internal addresses and domains to ensure recognized contacts stay unmarked" : "Halda sinu serveri sisemisi aadresse ja domeene. Nii tagatakse, et sinu poolt kinnitatud kontaktid jäävad esiletõstmata",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Halda sertifikaate",
     "Mailvelope" : "Mailvelope",
-    "A browser extension that enables easy OpenPGP encryption and decryption of emails" : "Brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
     "Mailvelope is enabled for the current domain." : "Mailvelope on selle domeeni puhul kasutusel.",
     "Step 1" : "1. samm",
     "Install the browser extension" : "Paigalda veebibrauseri laiendus/lisamoodul",
     "Step 2" : "2. samm",
     "Enable for the current domain" : "Luba  kasutamine selle domeeni puhul",
     "Assistance features" : "Abilise funktsionaalsused",
-    "Keyboard shortcuts" : "Klaviatuuri kiirklahvid",
+    "About" : "Rakenduse teave",
+    "Acknowledgements" : "Tänuavaldused",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
     "Compose new message" : "Koosta uus kiri",
     "Newer message" : "Uuem kiri",
     "Older message" : "Vane kiri",
@@ -174,9 +170,6 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
-    "About" : "Rakenduse teave",
-    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
-    "Mail version: {version}" : "E-postirakenduse versioon: {version}",
     "Title of the text block" : "Tekstiploki pealkiri",
     "Content of the text block" : "Tekstiploki sisu",
     "Ok" : "Sobib",
@@ -353,7 +346,6 @@ OC.L10N.register(
     "individual" : "individuaalne",
     "domain" : "domeen",
     "Remove" : "Eemalda",
-    "email" : "e-post",
     "Add internal address" : "Lisa sisene aadress",
     "Add internal email or domain" : "Lisa sisene e-posti aadress või domeen",
     "Itinerary for {type} is not supported yet" : "Reisiplaani tüüp pole veel toetatud: {type}",
@@ -371,6 +363,7 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
+    "Favorites" : "Lemmikud",
     "Load more follow ups" : "Laadi veel jätkukirju",
     "Important info" : "Oluline teave",
     "Load more important messages" : "Laadi veel olulisi kirju",
@@ -421,6 +414,8 @@ OC.L10N.register(
     "Moving" : "Teisaldan",
     "Moving thread" : "Teisaldan jutulõnga mujale",
     "Moving message" : "Teisaldan kirja",
+    "This account cannot connect" : "Selle kasutajakonto ühendamine ei õnnestu",
+    "Connection failed. Please verify your information and try again" : "Ühendamine ei õnnestunud. Palun kontrolli, kas kõik sisestatud teave on õige ja proovi uuesti",
     "Used quota: {quota}% ({limit})" : "Kasutatud kvoot: {quota}% ({limit})",
     "Used quota: {quota}%" : "Kasutatud kvoot: {quota}%",
     "Unable to create mailbox. The name likely contains invalid characters. Please try another name." : "Postkasti pole võimalik luua. Ilmselt on nimes keelatud tähemärke. Palun proovi mõnda muud nime.",
@@ -449,7 +444,6 @@ OC.L10N.register(
     "An error occurred, unable to rename the mailbox." : "Tekkis viga ja postkasti nime muutmine pole võimalik.",
     "Please wait 10 minutes before repairing again" : "Enne uuesti parandamist palun oota 10 minutit",
     "Mark all as read" : "Märgi loetuks",
-    "Mark all messages of this folder as read" : "Märgi kõik selle kausta kirjad loetuks",
     "Add subfolder" : "Lisa alamkaust",
     "Rename" : "Muuda nime",
     "Move folder" : "Teisalda kaust",
@@ -458,6 +452,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Kui sünkroniseerimisel tekib vigu, siis kustuta kohalikus seadmes puhverdatud andmed.",
     "Subscribed" : "Tellitud",
     "Sync in background" : "Sünkroniseeri taustal",
+    "Delete all messages" : "Kustuta kõik sõnumid",
     "Outbox" : "Saadetud kirjad",
     "Translate this message to {language}" : "Tõlgi see e-kiri sihtkeelde: {language}",
     "New message" : "Uus kiri",
@@ -540,8 +535,7 @@ OC.L10N.register(
     "Has attachments" : "Leidub manuseid",
     "Mentions me" : "Mainib mind",
     "Has attachment" : "Manusega",
-    "Last 7 days" : "Viimase 7 päeva jooksul",
-    "From me" : "Minult",
+    "To me" : "Mulle",
     "Enable mail body search" : "Otsi kirja sisust",
     "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve on väga võimas keel, mille abil saad koostada filtreid oma postkastide jaoks. Kui sinu e-posti teenusepakkuja seda võimalust toetab, siis saad Sievet kasutada ka siin rakenduses. Sieve on vajalik rakenduse automaatvastaja ja kirjafiltrite jaoks.",
     "Enable sieve filter" : "Võta Sieve filter kasutusele",
@@ -634,10 +628,15 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "Rong {trainNr}:  {depStation} → {arrStation}",
     "Train from {depStation} to {arrStation}" : "Rong: {depStation} → {arrStation}",
     "Train" : "Rong",
+    "Mark message as" : "Märgi sõnumi olekuks",
     "Add flag" : "Lisa tunnus",
     "Move into folder" : "Tõsta kausta",
     "Stop" : "Lõpeta",
     "Delete action" : "Kustuta tegevus",
+    "Answered" : "Vastatud",
+    "Deleted" : "Kustutatud",
+    "Flagged" : "Märgistatud",
+    "Seen" : "Nähtud",
     "Enter flag" : "Sisesta tunnus",
     "Stop ends all processing" : "Peatamisel kogu töötlemine lõppeb",
     "Sender" : "Saatja",
@@ -797,7 +796,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Oma e-posti konto lisamiseks palun võta ühendust oma peakasutajaga.",
     "All" : "Kõik",
     "Drafts" : "Mustandid",
-    "Favorites" : "Lemmikud",
     "Priority inbox" : "Olulised kirjad",
     "All inboxes" : "Kõik postkastid",
     "Inbox" : "Postkast",
@@ -832,33 +830,9 @@ OC.L10N.register(
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
     "Continue to %s" : "Jätka siia: %s",
-    "Search in the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
-    "Put my text to the bottom of a reply instead of on top of it." : "Sisesta minu tekst vastuse alla, mitte tema kohale",
-    "Use internal addresses" : "Kasuta sisemisi aadresse",
-    "Accounts" : "Kasutajakontod",
-    "Newest" : "Uusim",
-    "Oldest" : "Vanim",
-    "Reply text position" : "Vastuse teksti asukoht",
-    "Use Gravatar and favicon avatars" : "Kasuta Gravatari ja favikonide tunnuspilte",
-    "Register as application for mail links" : "Registreeri mailto: linke avava rakendusena",
-    "Create a new text block" : "Koosta uus tekstiplokk",
-    "Data collection consent" : "Nõusolek andmete kogumiseks",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Luba rakendusel koguda andmeid sinu kasutusharjumuste kohta. Nende andmete alusel rakendus kohendab oma seadistusi. Kogutud andmed on säilitatud vaid kohalikus serveris.",
-    "Trusted senders" : "Usaldatud saatjad",
-    "Internal addresses" : "Sisemised aadressid",
-    "Manage S/MIME certificates" : "Halda S/MIME sertifikaate",
-    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope on brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
-    "Step 1: Install Mailvelope browser extension" : "1. samm: Paigalda Mailvelope'i brauserilaiendus",
-    "Step 2: Enable Mailvelope for the current domain" : "2. samm: Võta Mailvelope selle domeeni puhul kasutusele",
-    "Contact or email address …" : "Kontakt või e-posti aadress…",
-    "Subject …" : "Teema…",
-    "Write message …" : "Koosta kiri…",
-    "Saving draft …" : "Salvestan kavandit…",
-    "Loading messages …" : "Laadin kirju…",
-    "Loading …" : "Laadin...",
-    "Contact name …" : "Kontakti nimi…",
-    "Signature …" : "Allkiri…",
-    "Saving new tag name …" : "Salvestan sildi uut nime…",
-    "Saving tag …" : "Salvestan silti…"
+    "Determine importance using machine learning" : "Määra olulisus masinõppe abil",
+    "Mark all messages of this folder as read" : "Märgi kõik selle kausta kirjad loetuks",
+    "Last 7 days" : "Viimase 7 päeva jooksul",
+    "From me" : "Minult"
 },
 "nplurals=2; plural=(n != 1);");
