@@ -113,28 +113,22 @@ OC.L10N.register(
     "Mail settings" : "Posta ezarpenak",
     "General" : "Orokorra",
     "Add mail account" : "Gehitu posta-kontua",
-    "Settings for:" : "Ezarpenak honentzat:",
     "Appearance" : "Itxura",
     "Layout" : "Diseinua",
-    "List" : "Zerrenda",
     "Vertical split" : "Banaketa bertikala",
     "Horizontal split" : "Banaketa horizontala",
+    "List" : "Zerrenda",
     "Sorting" : "Antolaketa",
     "Newest first" : "Berrienak lehenengo ",
     "Oldest first" : "Zaharrenak lehenengo",
-    "Search in body" : "Bilatu testuan",
-    "Gravatar settings" : "Gravatar ezarpenak",
-    "Mailto" : "Mailto",
-    "Register" : "Erregistratu",
     "Shared with me" : "Nirekin partekatuta",
-    "Privacy and security" : "Pribatutasuna eta segurtasuna",
+    "Privacy" : "Pribatutasuna",
     "Security" : "Segurtasuna",
-    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Nabarmendu kanpoko helbide elektronikoak ezaugarri hau gaituz, kudeatu barneko helbideak eta domeinuak kontaktu ezagunak markatu gabe geratuko direla bermatzeko.",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Kudeatu ziurtagiriak",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Laguntzailearen aukerak",
-    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
+    "About" : "Honi buruz",
     "Compose new message" : "Idatzi mezu berria",
     "Newer message" : "Mezu berriagoa",
     "Older message" : "Mezu zaharragoa",
@@ -145,7 +139,6 @@ OC.L10N.register(
     "Search" : "Bilatu",
     "Send" : "Bidali",
     "Refresh" : "Freskatu",
-    "About" : "Honi buruz",
     "Ok" : "Ados",
     "No certificate" : "Ziurtagiririk ez",
     "Certificate updated" : "Ziurtagiria eguneratu da",
@@ -301,7 +294,6 @@ OC.L10N.register(
     "individual" : "bakarkakoa",
     "domain" : "domeinua",
     "Remove" : "Kendu",
-    "email" : "posta elektronikoa",
     "Add internal address" : "Gehitu barneko helbidea",
     "Add internal email or domain" : "Gehitu barneko helbide elektronikoa edo domeinua",
     "Itinerary for {type} is not supported yet" : "{type} motarentzako ibilbidea ez da onartzen oraindik",
@@ -314,6 +306,7 @@ OC.L10N.register(
     "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mezuak automatikoki markatuko dira garrantzitsu bezala kontuan izanda zein mezurekin aritu zaren interakzioan edo zein markatu dituzun garratzitsu gisa. Hasieran garrantzia eskuz aldatu beharko duzu sistemari irakasteko, baina denborarekin hobetuko du.",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Erantzuteko eskatuz bidali zenituen emailak, baina egun batzuen ondoren erantzunik jasotzen ez dutenak hemen erakutsiko dira.",
+    "Favorites" : "Gogokoak",
     "Follow up" : "Segimendua egin",
     "Follow up info" : "Segimenduaren informazioa",
     "Important info" : "Informazio garrantzitsua",
@@ -387,7 +380,6 @@ OC.L10N.register(
     "An error occurred, unable to rename the mailbox." : "Akatsen bat gertatu da, ezin izan da postontzia berrizendatu.",
     "Please wait 10 minutes before repairing again" : "Mesedez, itxaron 10 minutu berriro konpondu aurretik",
     "Mark all as read" : "Markatu dena irakurrita bezala",
-    "Mark all messages of this folder as read" : "Markatu karpeta honetako mezu guztiak irakurrita bezala",
     "Add subfolder" : "Gehitu azpi-karpeta bat",
     "Rename" : "Berrizendatu",
     "Move folder" : "Lekuz aldatu karpeta",
@@ -464,8 +456,6 @@ OC.L10N.register(
     "Has attachments" : "Eranskinak ditu",
     "Mentions me" : "Ni aipatzen nau",
     "Has attachment" : "Eranskina dauka",
-    "Last 7 days" : "Azken 7 egunetan",
-    "From me" : "Nigandik",
     "Enable mail body search" : "Gaitu posten testuko bilaketa",
     "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve zure postontzirako iragazkiak idazteko hizkuntza indartsua da. Posta elektronikoko gidoiak kudea ditzakezu. Sieve ere behar da Auto-erantzule eta Iragazkiak erabiltzeko.",
     "Enable sieve filter" : "Gaitu sieve iragazkia",
@@ -548,6 +538,7 @@ OC.L10N.register(
     "Train" : "Trena",
     "Stop" : "Gelditu",
     "Delete action" : "Ezabatu ekintza",
+    "Deleted" : "Ezabatuta",
     "Recipient" : "Hartzailea",
     "Delete filter" : "Ezabatu iragazkia",
     "Delete mail filter {filterName}?" : "Ezabatu {filterName} posta-iragazkia?",
@@ -579,7 +570,6 @@ OC.L10N.register(
     "There was an error when provisioning accounts." : "Errore bat gertatu da kontuak hornitzean.",
     "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\"-ren kontuak behar bezala ezabatu dira.",
     "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errorea gertatu da \"{domain}\"-ren kontuak ezabatzean.",
-    "Could not save default classification setting" : "Ezin izan da sailkapen-ezarpen lehenetsia gorde",
     "Mail app" : "Posta elektroniko aplikazioa",
     "The mail app allows users to read mails on their IMAP accounts." : "Posta elektroniko aplikazio honek aukera ematen die erabiltzaileei IMAP kontuetako mezuak irakurtzeko.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hemen instantzia osoko ezarpenak aurkitu ditzakezu. Erabiltzailearen ezarpen espezifikoak aplikazioan bertan daude (beheko ezkerreko izkinan).",
@@ -600,9 +590,6 @@ OC.L10N.register(
     "Enable text processing through LLMs" : "Gaitu testuen prozesamendua LLMen bidez",
     "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Posta aplikazioak erabiltzailearen datuak prozesatu ditzake konfiguratutako hizkuntza-ereduaren laguntzaz eta laguntza-funtzioak eskain ditzake, hala nola harien laburpenak, erantzun adimendunak eta gertaeren agendak.",
     "Enable LLM processing" : "Gaitu LLM prozesatzea",
-    "Enable classification by importance by default" : "Gaitu garrantziaren araberako sailkapena modu lehenetsian",
-    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Posta aplikazioak sarrerako mezu elektronikoak garrantziaren arabera sailka ditzake ikaskuntza automatikoa erabiliz. Ezaugarri hau lehenespenez gaituta dago, baina lehenespenez desgaitu daiteke hemen. Erabiltzaile indibidualek beren kontuetarako funtzioa aldatzeko aukera izango dute oraindik.",
-    "Enable classification of important mails by default" : "Gaitu mezu garrantzitsuen sailkapena modu lehenetsian",
     "Anti Spam Service" : "Anti spam zerbitzua",
     "You can set up an anti spam service email address here." : "Hemen spamaren aurkako zerbitzuaren helbide elektronikoa konfigura dezakezu.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Spam gisa markatutako edozein mezu elektroniko spamaren aurkako zerbitzura bidaliko da.",
@@ -688,7 +675,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "E-mail kontua gehitzeko, kontaktatu zure administratzailearekin, mesedez.",
     "All" : "Denak",
     "Drafts" : "Zirriborroak",
-    "Favorites" : "Gogokoak",
     "Priority inbox" : "Lehentasuneko sarrera",
     "All inboxes" : "Postontzi guztiak",
     "Inbox" : "Sarrera-ontzia",
@@ -720,29 +706,12 @@ OC.L10N.register(
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
     "Continue to %s" : "Jarraitu hona: %s",
-    "Search in the body of messages in priority Inbox" : "Bilatu sarrera-ontziko mezuetan",
-    "Put my text to the bottom of a reply instead of on top of it." : "Jarri nire testua erantzunaren behealdean, goian jarri beharrean.",
-    "Use internal addresses" : "Erabili barneko helbideak",
-    "Accounts" : "Kontuak",
-    "Newest" : "Berrienak",
-    "Oldest" : "Zaharrenak",
-    "Reply text position" : "Erantzun testuaren posizioa",
-    "Use Gravatar and favicon avatars" : "Erabili Gravatar eta favicon avatarrak",
-    "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
-    "Data collection consent" : "Datuak biltzeko baimena",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
-    "Trusted senders" : "Bidaltzaile fidagarriak",
-    "Internal addresses" : "Barneko helbideak",
-    "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak",
-    "Contact or email address …" : "Kontaktua edo posta helbidea…",
-    "Subject …" : "Gaia…",
-    "Write message …" : "Idatzi mezua...",
-    "Saving draft …" : "Zirriborroa gordetzen...",
-    "Loading messages …" : "Mezuak kargatzen ...",
-    "Loading …" : "Kargatzen...",
-    "Contact name …" : "Kontaktu izena ...",
-    "Signature …" : "Sinadura...",
-    "Saving new tag name …" : "Etiketa-izen berria gordetzen ...",
-    "Saving tag …" : "Etiketa gordetzen"
+    "Mark all messages of this folder as read" : "Markatu karpeta honetako mezu guztiak irakurrita bezala",
+    "Last 7 days" : "Azken 7 egunetan",
+    "From me" : "Nigandik",
+    "Could not save default classification setting" : "Ezin izan da sailkapen-ezarpen lehenetsia gorde",
+    "Enable classification by importance by default" : "Gaitu garrantziaren araberako sailkapena modu lehenetsian",
+    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Posta aplikazioak sarrerako mezu elektronikoak garrantziaren arabera sailka ditzake ikaskuntza automatikoa erabiliz. Ezaugarri hau lehenespenez gaituta dago, baina lehenespenez desgaitu daiteke hemen. Erabiltzaile indibidualek beren kontuetarako funtzioa aldatzeko aukera izango dute oraindik.",
+    "Enable classification of important mails by default" : "Gaitu mezu garrantzitsuen sailkapena modu lehenetsian"
 },
 "nplurals=2; plural=(n != 1);");
