@@ -104,11 +104,11 @@ OC.L10N.register(
     "Sorting" : "Rendezés",
     "Newest first" : "Legújabb elöl",
     "Oldest first" : "Régebbiek elöl",
-    "Register" : "Regisztráció",
     "Shared with me" : "Megosztva velem",
+    "Privacy" : "Adatvédelem",
     "Security" : "Biztonság",
     "Manage certificates" : "Tanúsítványok kezelése",
-    "Keyboard shortcuts" : "Gyorsbillentyűk",
+    "About" : "Névjegy",
     "Compose new message" : "Új üzenet írása",
     "Newer message" : "Újabb üzenet",
     "Older message" : "Régebbi üzenet",
@@ -119,7 +119,6 @@ OC.L10N.register(
     "Search" : "Keresés",
     "Send" : "Küldés",
     "Refresh" : "Frissítés",
-    "About" : "Névjegy",
     "Ok" : "Rendben",
     "No certificate" : "Nincs tanúsítvány",
     "Certificate updated" : "Tanúsítvány frissítve",
@@ -267,7 +266,6 @@ OC.L10N.register(
     "individual" : "egyéni",
     "domain" : "domain",
     "Remove" : "Eltávolítás",
-    "email" : "e-mail",
     "Add internal address" : "Belső cím hozzáadása",
     "Add internal email or domain" : "Belső e-mail vagy tartomány hozzáadása",
     "Itinerary for {type} is not supported yet" : "A(z) {type} útiterve még nem támogatott",
@@ -279,6 +277,7 @@ OC.L10N.register(
     "Choose target folder" : "Válasszon célmappát",
     "No more submailboxes in here" : "Nem találhatók további alpostafiókok",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Az üzeneteket automatikusan fontosként jelöli meg az alapján, hogy mely üzenetekre reagált, vagy jelölt meg fontosként. Kezdetben lehet, hogy kézzel megváltoztatnia a fontosságot és ezzel kell tanítania a rendszert, de ez az idő múlásával javulni fog.",
+    "Favorites" : "Kedvencek",
     "Follow up" : "Emlékeztető",
     "Follow up info" : "Emlékeztető információ",
     "Important info" : "Fontos információ",
@@ -343,7 +342,6 @@ OC.L10N.register(
     "Delete folder" : "Mappa törlése",
     "An error occurred, unable to rename the mailbox." : "Hiba történt, nem sikerült átnevezni a postafiókot.",
     "Mark all as read" : "Összes megjelölése olvasottként",
-    "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
     "Add subfolder" : "Almappa hozzáadás",
     "Rename" : "Átnevezés",
     "Move folder" : "Mappa áthelyezése",
@@ -351,6 +349,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Törölje a helyileg gyorsítótárazott adatokat, ha a szinkronizálással kapcsolatban problémák merülnének fel.",
     "Subscribed" : "Feliratkozott",
     "Sync in background" : "Szinkronizálás a háttérben",
+    "Delete all messages" : "Összes üzenet törlése",
     "Outbox" : "Kimenő üzenetek",
     "New message" : "Új üzenet",
     "Edit message" : "Üzenet szerkesztése",
@@ -406,7 +405,6 @@ OC.L10N.register(
     "Select tags" : "Címkék kiválasztása",
     "Marked as" : "Megjelölés mint",
     "Has attachments" : "Van melléklete",
-    "Last 7 days" : "Előző 7 nap",
     "Sieve Port" : "Levélszűrő port",
     "Custom" : "Egyéni",
     "Sieve User" : "Levélszűrő felhasználó",
@@ -478,6 +476,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Vonat {depStation} és {arrStation} között",
     "Train" : "Vonat",
     "Stop" : "Leállítás",
+    "Deleted" : "Törölve",
     "Recipient" : "Címzett",
     "Delete filter" : "Szűrő törlése",
     "Help" : "Súgó",
@@ -598,7 +597,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Levelezőfiók hozzáadásához lépjen kapcsolatba a rendszergazdával.",
     "All" : "Összes",
     "Drafts" : "Piszkozatok",
-    "Favorites" : "Kedvencek",
     "Priority inbox" : "Kiemelt bejövő levelek",
     "All inboxes" : "Összes bejövő levél",
     "Inbox" : "Bejövő",
@@ -630,24 +628,7 @@ OC.L10N.register(
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
     "Continue to %s" : "Folytatás ide: %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "A szöveg a válasz aljára helyezése a teteje helyett.",
-    "Accounts" : "Fiókok",
-    "Newest" : "Legújabb",
-    "Oldest" : "Legrégebbi",
-    "Use Gravatar and favicon avatars" : "Gravatar és favicon profilképek használata",
-    "Register as application for mail links" : "Alkalmazás beállítása a levélhivatkozásokhoz",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Engedélyezés az alkalmazásnak, hogy az adatokat gyűjtsön az interakcióiról. Az adatok alapján az alkalmazás alkalmazkodni fog a használati szokásaihoz. Az adatok helyben lesznek tárolva.",
-    "Trusted senders" : "Megbízható küldők",
-    "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése",
-    "Contact or email address …" : "Címzett vagy e-mail-cím…",
-    "Subject …" : "Tárgy…",
-    "Write message …" : "Üzenet írása…",
-    "Saving draft …" : "Piszkozat mentése…",
-    "Loading messages …" : "Üzenetek betöltése…",
-    "Loading …" : "Betöltés…",
-    "Contact name …" : "Névjegyhez tartozó név…",
-    "Signature …" : "Aláírás…",
-    "Saving new tag name …" : "Új címkenév mentése…",
-    "Saving tag …" : "Címke mentése…"
+    "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
+    "Last 7 days" : "Előző 7 nap"
 },
 "nplurals=2; plural=(n != 1);");
