@@ -27,16 +27,14 @@ OC.L10N.register(
     "List" : "Daftar",
     "Newest first" : "Terbaru",
     "Oldest first" : "Paling lama",
-    "Register" : "Daftar",
     "Shared with me" : "Dibagikan dengan saya",
     "Security" : "Keamanan",
-    "Keyboard shortcuts" : "Pintasan keyboard",
+    "About" : "Tentang",
     "Archive" : "Arsip",
     "Delete" : "Hapus",
     "Search" : "Cari",
     "Send" : "Kirim",
     "Refresh" : "Segarkan",
-    "About" : "Tentang",
     "Ok" : "Oke",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
@@ -59,11 +57,11 @@ OC.L10N.register(
     "Accept" : "Terima",
     "Decline" : "Tolak",
     "Remove" : "Buang",
-    "email" : "email",
     "Today" : "Hari ini",
     "Last week" : "Minggu lalu",
     "Last month" : "Bulan lalu",
     "Choose target folder" : "Pilih folder target",
+    "Favorites" : "Disukai",
     "Other" : "Lainnya",
     "Forward" : "Teruskan",
     "Translate" : "Terjemahkan",
@@ -95,6 +93,7 @@ OC.L10N.register(
     "Unsubscribe" : "Berhenti berlangganan",
     "Untitled event" : "Acara tanpa judul",
     "(organizer)" : "(penyelenggara)",
+    "Deleted" : "Dihapus",
     "Recipient" : "Penerima",
     "Help" : "Bantuan",
     "contains" : "mengandung",
@@ -119,7 +118,6 @@ OC.L10N.register(
     "Connect your mail account" : "Hubungkan akun email Anda",
     "All" : "Semua",
     "Drafts" : "Konsep",
-    "Favorites" : "Disukai",
     "All inboxes" : "Semua kotak masuk",
     "Inbox" : "Kotak masuk",
     "Junk" : "Sampah",
@@ -130,8 +128,6 @@ OC.L10N.register(
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
-    "Continue to %s" : "Lanjutkan ke %s",
-    "Accounts" : "Accounts",
-    "Loading …" : "Memuat …"
+    "Continue to %s" : "Lanjutkan ke %s"
 },
 "nplurals=1; plural=0;");
