@@ -91,14 +91,13 @@ OC.L10N.register(
     "Sorting" : "Ordina",
     "Newest first" : "Prima i più recenti",
     "Oldest first" : "Prima i più datati",
-    "Gravatar settings" : "Impostazioni Gravatar",
-    "Register" : "Registra",
     "Shared with me" : "Condivisi con me",
+    "Privacy" : "Riservatezza",
     "Security" : "Sicurezza",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Gestisci certificati",
     "Mailvelope" : "Mailvelope",
-    "Keyboard shortcuts" : "Scorciatoie da tastiera",
+    "About" : "Informazioni",
     "Compose new message" : "Componi nuovo messaggio",
     "Newer message" : "Messaggio più recente",
     "Older message" : "Messaggio più datato",
@@ -109,7 +108,6 @@ OC.L10N.register(
     "Search" : "Cerca",
     "Send" : "Invia",
     "Refresh" : "Aggiorna",
-    "About" : "Informazioni",
     "Ok" : "Ok",
     "No certificate" : "Nessun certificato",
     "Certificate updated" : "Certificato aggiornato",
@@ -247,6 +245,7 @@ OC.L10N.register(
     "Choose target folder" : "Scegli la cartella di destinazione",
     "No more submailboxes in here" : "Qui non ci sono altre sotto-caselle di posta",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "I messaggi saranno automaticamente contrassegnati come importanti in base ai messaggi con cui hai interagito o contrassegnati come importanti. All'inizio potresti dover cambiare manualmente l'importanza per addestrare il sistema, ma migliorerà nel tempo.",
+    "Favorites" : "Preferiti",
     "Important info" : "Informazione importante",
     "Other" : "Altro",
     "Could not send mdn" : "Impossibile inviare mdn",
@@ -301,7 +300,6 @@ OC.L10N.register(
     "Delete folder {name}" : "Elimina cartella {name}",
     "An error occurred, unable to rename the mailbox." : "Si è verificato un errore, impossibile rinominare la casella di posta.",
     "Mark all as read" : "Marca tutti come letti",
-    "Mark all messages of this folder as read" : "Marca tutti i messaggi di questa cartella come letti",
     "Add subfolder" : "Aggiungi sottocartella",
     "Rename" : "Rinomina",
     "Move folder" : "Sposta cartella",
@@ -359,7 +357,6 @@ OC.L10N.register(
     "Tags" : "Etichette",
     "Select tags" : "Seleziona etichette",
     "Has attachments" : "Ha allegati",
-    "Last 7 days" : "Ultimi 7 giorni",
     "Sieve Port" : "Porta Sieve",
     "IMAP credentials" : "Credenziali IMAP",
     "Custom" : "Personalizzato",
@@ -412,6 +409,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Treno da {depStation} a {arrStation}",
     "Train" : "Treno",
     "Stop" : "Ferma",
+    "Deleted" : "Eliminato",
     "Recipient" : "Destinatario",
     "Help" : "Assistenza",
     "contains" : "contiene",
@@ -526,7 +524,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Per aggiungere un account di posta, contatta il tuo amministratore.",
     "All" : "Tutti",
     "Drafts" : "Bozze",
-    "Favorites" : "Preferiti",
     "Priority inbox" : "Posta in arrivo prioritaria",
     "All inboxes" : "Tutte le cartelle di posta in arrivo",
     "Inbox" : "Posta in arrivo",
@@ -556,24 +553,7 @@ OC.L10N.register(
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
     "Continue to %s" : "Continua su %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Inserisci il mio testo in fondo alla risposta invece che sopra.",
-    "Accounts" : "Account",
-    "Newest" : "Più recente",
-    "Oldest" : "Il più datato",
-    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
-    "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
-    "Trusted senders" : "Mittenti affidabili",
-    "Manage S/MIME certificates" : "Gestisci i certificati S/MIME",
-    "Contact or email address …" : "Contatto o indirizzo email...",
-    "Subject …" : "Oggetto...",
-    "Write message …" : "Scrivi messaggio...",
-    "Saving draft …" : "Salvataggio bozza…",
-    "Loading messages …" : "Caricamento messaggi...",
-    "Loading …" : "Caricamento in corso...",
-    "Contact name …" : "Nome contatto …",
-    "Signature …" : "Firma...",
-    "Saving new tag name …" : "Salvataggio nuovo nome della etichetta...",
-    "Saving tag …" : "Salvataggio etichetta …"
+    "Mark all messages of this folder as read" : "Marca tutti i messaggi di questa cartella come letti",
+    "Last 7 days" : "Ultimi 7 giorni"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
