@@ -100,22 +100,18 @@ OC.L10N.register(
     "Add mail account" : "메일 계정 추가",
     "Appearance" : "외형",
     "Layout" : "레이아웃",
-    "List" : "목록",
     "Vertical split" : "수직 분할",
     "Horizontal split" : "수평 분할",
+    "List" : "목록",
     "Sorting" : "정렬",
     "Newest first" : "최신순",
     "Oldest first" : "오래된순",
-    "Search in body" : "본문 검색",
-    "Gravatar settings" : "Gravatar 설정",
-    "Register" : "등록",
     "Text blocks" : "텍스트 블록",
     "New text block" : "새로운 텍스트 블록",
-    "Privacy and security" : "개인정보 및 보안",
+    "Privacy" : "프라이버시",
     "Security" : "보안",
     "S/MIME" : "S/MIME",
     "Mailvelope" : "Mailvelope",
-    "Keyboard shortcuts" : "키보드 단축키",
     "Compose new message" : "새 메시지 작성",
     "Newer message" : "새로운 메시지",
     "Older message" : "오래된 메시지",
@@ -273,7 +269,6 @@ OC.L10N.register(
     "individual" : "개별",
     "domain" : "도메인",
     "Remove" : "삭제",
-    "email" : "이메일",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "이 메시지를 보관 폴더로 옮기거나 현재 폴더에서 삭제할 수 없습니다",
     "Today" : "오늘",
     "Yesterday" : "어제",
@@ -281,6 +276,7 @@ OC.L10N.register(
     "Choose target folder" : "폴더 선택",
     "No more submailboxes in here" : "더 이상의 하위 편지함 없음",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "사용자의 메시지 상호작용, 중요 표시 정보 등을 바탕으로 특정 메시지가 자동으로 중요 표시됩니다. 초기 단계에서는 시스템의 학습을 위해 사용자가 중요 여부를 수동으로 변경하게 될 수 있으나, 이는 점차 개선될 것입니다.",
+    "Favorites" : "즐겨찾기",
     "Important info" : "중요 정보",
     "Other" : "기타",
     "Could not send mdn" : "mdn을 보낼 수 없음",
@@ -349,6 +345,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "동기화 관련 문제가 발생했을 경우 로컬에서 캐시된 데이터를 비우십시오.",
     "Subscribed" : "구독함",
     "Sync in background" : "백그라운드에서 동기화",
+    "Delete all messages" : "모든 메시지 삭제",
     "Outbox" : "보낸 편지함",
     "New message" : "새로운 메시지",
     "Edit message" : "메시지 편집",
@@ -409,7 +406,6 @@ OC.L10N.register(
     "Select tags" : "태그 선택",
     "Marked as" : "다음으로 표시됨",
     "Has attachments" : "첨부파일 있음",
-    "Last 7 days" : "지난 7일",
     "Enable mail body search" : "메일 본문 검색 활성화",
     "Sieve Port" : "Sieve 포트",
     "Custom" : "사용자 정의",
@@ -482,6 +478,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 {trainNr}번 열차",
     "Train from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 열차",
     "Train" : "기차",
+    "Deleted" : "삭제됨",
     "Recipient" : "받는 사람",
     "Delete filter" : "필터 삭제",
     "Help" : "도움말",
@@ -607,7 +604,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
     "All" : "모두",
     "Drafts" : "임시 보관함",
-    "Favorites" : "즐겨찾기",
     "Priority inbox" : "우선 편지함",
     "All inboxes" : "모든 받은 편지함",
     "Inbox" : "받은 편지함",
@@ -639,29 +635,6 @@ OC.L10N.register(
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동",
-    "Search in the body of messages in priority Inbox" : "우선 편지함에서 메시지 본문 검색",
-    "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
-    "Accounts" : "계정",
-    "Newest" : "최신순",
-    "Oldest" : "과거순",
-    "Reply text position" : "답장 문구 위치",
-    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
-    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
-    "Create a new text block" : "새로운 텍스트 블록 생성",
-    "Data collection consent" : "데이터 수집 동의",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
-    "Trusted senders" : "신뢰할 수 있는 발신자",
-    "Internal addresses" : "내부 주소",
-    "Manage S/MIME certificates" : "S/MIME 인증서 관리",
-    "Contact or email address …" : "연락처 또는 이메일 주소 ...",
-    "Subject …" : "제목...",
-    "Write message …" : "메시지 작성중...",
-    "Saving draft …" : "초안 저장 중...",
-    "Loading messages …" : "메시지를 불러오는 중 ...",
-    "Loading …" : "불러오는 중 …",
-    "Contact name …" : "연락처 이름 ...",
-    "Signature …" : "서명 …",
-    "Saving new tag name …" : "새 태그명 저장 ...",
-    "Saving tag …" : "태그 저장하는 중 ..."
+    "Last 7 days" : "지난 7일"
 },
 "nplurals=1; plural=0;");
