@@ -31,15 +31,14 @@ OC.L10N.register(
     "Cancel" : "Anullar",
     "General" : "Generals",
     "List" : "Tièra",
-    "Register" : "S'inscriure",
+    "Privacy" : "Confidencialitat",
     "Security" : "Seguretat",
-    "Keyboard shortcuts" : "Acorchis de clavièr",
+    "About" : "A prepaus",
     "Archive" : "Archius",
     "Delete" : "Suprimir",
     "Search" : "Recercar",
     "Send" : "Mandar",
     "Refresh" : "Refrescar",
-    "About" : "A prepaus",
     "From" : "De",
     "Monday morning" : "Diluns matin",
     "Choose" : "Causir",
@@ -65,6 +64,7 @@ OC.L10N.register(
     "Today" : "Uèi",
     "Last week" : "La setmana passada",
     "Last month" : "Lo mes passat",
+    "Favorites" : "Favorits",
     "Other" : "Autre",
     "Translate" : "Tradurre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
@@ -89,6 +89,7 @@ OC.L10N.register(
     "Translating" : "Traduccion",
     "Untitled event" : "Eveniment sens títol",
     "Train" : "Tren",
+    "Deleted" : "Suprimit",
     "Help" : "Ajuda",
     "Actions" : "Accions",
     "delete" : "suprimir",
@@ -108,7 +109,6 @@ OC.L10N.register(
     "Account connected" : "Compte connectat",
     "All" : "Tot",
     "Drafts" : "Borrolhons",
-    "Favorites" : "Favorits",
     "All inboxes" : "Totas las bóstias",
     "Inbox" : "Bóstia de recepcion",
     "Junk" : "Indesirables",
@@ -118,9 +118,6 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "Message sent" : "Messatge mandat",
     "Error loading message" : "Error al moment del cargament del messatge",
-    "Continue to %s" : "Contunhar cap a %s",
-    "Accounts" : "Accounts",
-    "Write message …" : "Escriure un messatge…",
-    "Loading …" : "Cargament…"
+    "Continue to %s" : "Contunhar cap a %s"
 },
 "nplurals=2; plural=(n > 1);");
