@@ -54,22 +54,54 @@ OC.L10N.register(
     "Email address" : "Endereço de email",
     "Add alias" : "Adicionar alcunha",
     "Cancel" : "Cancelar",
+    "Search the body of messages in priority Inbox" : "Pesquise o corpo das mensagens na Caixa de entrada prioritária.",
+    "Highlight external addresses" : "Destacar endereços externos",
+    "Mail settings" : "Definições de e-mail",
     "General" : "Geral",
+    "Set as default mail app" : "Definir como aplicação de e-mail predefinida",
     "Add mail account" : "Adicionar conta de email",
+    "Appearance" : "Aspeto",
+    "Show all messages in thread" : "Mostrar todas as mensagens da conversa",
+    "When off, only the selected message will be shown" : "Quando desativado, apenas a mensagem selecionada será apresentada.",
+    "Layout" : "Esquema",
+    "Vertical split" : "Divisão vertical",
+    "Horizontal split" : "Divisão horizontal",
     "List" : "Lista",
+    "Sorting" : "Ordenação",
     "Newest first" : "Recentes primeiro",
     "Oldest first" : "Antigos primeiro",
-    "Register" : "Registar",
+    "Avatars from Gravatar and favicons" : "Avatares do Gravatar e favicons",
+    "Reply position" : "Posição de resposta",
+    "Top" : "Topo",
+    "Bottom" : "Fundo",
+    "Text blocks" : "Blocos de texto",
+    "Reusable pieces of text that can be inserted in messages" : "Excertos de texto reutilizáveis ​​que podem ser inseridos nas mensagens.",
+    "New text block" : "Novo bloco de texto",
     "Shared with me" : "Partilhadas comigo",
+    "Privacy" : "Privacidade",
+    "Data collection" : "Recolha de dados",
+    "Allow the app to collect and process data locally to adapt to your preferences" : "Permitir que a aplicação recolha e processe dados localmente para se adaptar às suas preferências.",
+    "Always show images from" : "Mostrar sempre imagens de",
     "Security" : "Segurança",
-    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Manage your internal addresses and domains to ensure recognized contacts stay unmarked" : "Faça a gestão dos seus endereços e domínios internos para garantir que os contactos reconhecidos permanecem sem marcação.",
+    "Manage certificates" : "Gerir certificados",
+    "Mailvelope" : "Mailvelope",
+    "Mailvelope is enabled for the current domain." : "O Mailvelope está ativado para o domínio atual",
+    "Install the browser extension" : "Instalar a extensão do browser",
+    "Enable for the current domain" : "Ativar para o domínio atual",
+    "About" : "Sobre",
+    "Acknowledgements" : "Reconhecimentos",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Esta aplicação inclui o CKEditor, um editor de código aberto. Copyright © Colaboradores do CKEditor. Licenciado sob a GPLv2.",
     "Compose new message" : "Compor nova mensagem",
+    "Newer message" : "Mensagem mais recente",
+    "Older message" : "Mensagem mais antiga",
+    "Toggle star" : "Alternar estrela",
+    "Toggle unread" : "Alternar entre não lidos",
     "Archive" : "Arquivar",
     "Delete" : "Eliminar",
     "Search" : "Pesquisar",
     "Send" : "Enviar",
     "Refresh" : "Atualizar",
-    "About" : "Sobre",
     "Ok" : "CONFIRMAR",
     "From" : "De",
     "Select account" : "Selecionar uma conta",
@@ -99,6 +131,7 @@ OC.L10N.register(
     "Edit as new message" : "Editar como nova mensagem",
     "Download message" : "Transferir mensagem",
     "Load more" : "Carregar mais",
+    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Editar etiquetas para {number}","Editar etiquetas para {number}","Editar etiquetas para {number}"],
     "Could not create event" : "Não foi possível criar o evento",
     "Create event" : "Criar evento",
     "All day" : "Todo o dia",
@@ -112,12 +145,13 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "domínio",
     "Remove" : "Remover",
-    "email" : "email",
+    "Add internal address" : "Adicionar endereço interno",
     "Last hour" : "Ultima hora",
     "Today" : "Hoje",
     "Last week" : "Ultima semana",
     "Last month" : "Ultimo mês",
     "Choose target folder" : "Escolher pasta de destino",
+    "Favorites" : "Favoritos",
     "Important info" : "Informação importante",
     "Other" : "Outro",
     "Notify the sender" : "Notificar o remetente",
@@ -174,19 +208,22 @@ OC.L10N.register(
     "Body" : "Corpo",
     "Date" : "Data",
     "Tags" : "Etiquetas",
-    "Last 7 days" : "Últimos 7 dias",
+    "Select tags" : "Selecione etiquetas",
     "Custom" : "Personalizado",
     "Save signature" : "Guardar assinatura",
     "Message source" : "Fonte da mensagem",
     "Tag already exists" : "A etiqueta já existe",
+    "Add default tags" : "Adicionar etiquetas padrão",
     "Not found" : "Não  encontrado",
     "Reply to sender only" : "Resposta apenas ao remetente",
+    "No senders are trusted at the moment." : "Nenhum remetente é confiável no momento.",
     "Untitled event" : "Evento sem título",
     "Import into {calendar}" : "Importar para {calendar}",
     "Event imported into {calendar}" : "Evento importado para {calendar}",
     "Airplane" : "Avião",
     "Reservation {id}" : "Reserva {id}",
     "Train" : "Comboio",
+    "Deleted" : "Eliminado",
     "Recipient" : "Destinatário",
     "Help" : "Ajuda",
     "contains" : "contém",
@@ -210,6 +247,8 @@ OC.L10N.register(
     "Valid until" : "Válido até",
     "Certificate" : "Certificado",
     "Submit" : "Submeter",
+    "No text blocks available" : "Não existem blocos de texto disponíveis.",
+    "Guest" : "Convidado",
     "Group" : "Grupo",
     "Shared" : "Partilhados",
     "Shares" : "Partilhas",
@@ -217,7 +256,6 @@ OC.L10N.register(
     "Connect your mail account" : "Ligue a sua conta de e-mail",
     "All" : "Todos",
     "Drafts" : "Rascunhos",
-    "Favorites" : "Favoritos",
     "Priority inbox" : "Caixa de entrada prioritária",
     "All inboxes" : "Todas as caixas de entrada",
     "Inbox" : "Caixa de Entrada",
@@ -237,18 +275,7 @@ OC.L10N.register(
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
     "Continue to %s" : "Continuar para %s",
-    "Accounts" : "Contas",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
-    "Register as application for mail links" : "Registar como aplicação para ligações de correio",
-    "Trusted senders" : "Remetentes confiáveis",
-    "Contact or email address …" : "Contacto ou endereço de email",
-    "Subject …" : "Assunto...",
-    "Write message …" : "Nova mensagem...",
-    "Saving draft …" : "A guardar rascunho ...",
-    "Loading …" : "A carregar...",
-    "Contact name …" : "Nome do contacto...",
-    "Signature …" : "Assinatura..."
+    "Determine importance using machine learning" : "Determinar a importância usando aprendizagem de máquina",
+    "Last 7 days" : "Últimos 7 dias"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
