@@ -32,10 +32,10 @@ OC.L10N.register(
     "Add mail account" : "Shto llogarinë e postës elektronike",
     "Newest first" : "Më i riu i pari",
     "Oldest first" : "Më i vjetri i pari",
-    "Register" : "Regjistrohu",
+    "Privacy" : "Privatësi",
     "Security" : "Siguria",
     "Manage certificates" : "Menaxhoni certifikatat",
-    "Keyboard shortcuts" : "Shkurtoret e tastierës",
+    "About" : "Rreth",
     "Newer message" : "Mesazhe më të reja",
     "Older message" : "Mesazhe më të vjetra",
     "Toggle star" : "Toggle star",
@@ -45,7 +45,6 @@ OC.L10N.register(
     "Search" : "Kërko",
     "Send" : "Dërgo",
     "Refresh" : "Rifresko",
-    "About" : "Rreth",
     "Ok" : "Në rregull",
     "Select account" : "Përzgjidhni llogari",
     "Subject" : "Temë",
@@ -71,8 +70,8 @@ OC.L10N.register(
     "Accept" : "Prano",
     "Decline" : "Refuzo",
     "Remove" : "Hiq",
-    "email" : "postë elektronike",
     "Today" : "Sot",
+    "Favorites" : "Favorites",
     "Other" : "Tjetër",
     "Forward" : "Përpara",
     "Translate" : "Përkthe",
@@ -108,6 +107,7 @@ OC.L10N.register(
     "Delete tag" : "Fshi etiketën",
     "Tag already exists" : "Etiketa ekziston",
     "Add tag" : "Shto etiketim",
+    "Deleted" : "E fshirë",
     "Recipient" : "Marrës",
     "Help" : "Ndihmë",
     "matches" : "përputhje",
@@ -130,7 +130,6 @@ OC.L10N.register(
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Drafts" : "Skica",
-    "Favorites" : "Favorites",
     "All inboxes" : "Krejt kutitë e postës",
     "Inbox" : "Inbox",
     "Junk" : "Të pavlera",
@@ -145,7 +144,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
     "Redirect" : "Ridrejtoje",
     "The link leads to %s" : "Lidhja shpie te %s",
-    "Continue to %s" : "Vazhdo te %s",
-    "Accounts" : "Llogari"
+    "Continue to %s" : "Vazhdo te %s"
 },
 "nplurals=2; plural=(n != 1);");
