@@ -23,15 +23,14 @@ OC.L10N.register(
     "Appearance" : "ลักษณะที่ปรากฏ",
     "Newest first" : "ใหม่ที่สุดก่อน",
     "Oldest first" : "เก่าที่สุดก่อน",
-    "Register" : "ลงทะเบียน",
+    "Privacy" : "ความเป็นส่วนตัว",
     "Security" : "ความปลอดภัย",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "About" : "เกี่ยวกับ",
     "Archive" : "ที่เก็บถาวร",
     "Delete" : "ลบ",
     "Search" : "ค้นหา",
     "Send" : "ส่ง",
     "Refresh" : "รีเฟรช",
-    "About" : "เกี่ยวกับ",
     "Ok" : "ตกลง",
     "Choose" : "เลือก",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
@@ -53,6 +52,7 @@ OC.L10N.register(
     "Last week" : "สัปดาห์ที่แล้ว",
     "Last month" : "เดือนที่แล้ว",
     "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
+    "Favorites" : "รายการโปรด",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
     "Translate" : "แปลภาษา",
@@ -75,10 +75,10 @@ OC.L10N.register(
     "Close" : "ปิด",
     "Date" : "วันที่",
     "Tags" : "แท็ก",
-    "Last 7 days" : "ภายใน 7 วัน",
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
     "Not found" : "ไม่พบ",
+    "Deleted" : "ลบแล้ว",
     "Help" : "ช่วยเหลือ",
     "Actions" : "การกระทำ",
     "Priority" : "ลำดับความสำคัญ",
@@ -99,7 +99,6 @@ OC.L10N.register(
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
-    "Favorites" : "รายการโปรด",
     "All inboxes" : "กล่องขาเข้าทั้งหมด",
     "Inbox" : "กล่องขาเข้า",
     "Junk" : "อีเมลขยะ",
@@ -110,6 +109,6 @@ OC.L10N.register(
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
     "Continue to %s" : "ดำเนินการต่อไปที่ %s",
-    "Accounts" : "บัญชี"
+    "Last 7 days" : "ภายใน 7 วัน"
 },
 "nplurals=1; plural=0;");
