@@ -121,9 +121,8 @@ class Version1130Date20220412111833 extends SimpleMigrationStep {
 
 		if (!$isSqlite) {
 			// Change primary column to bigint
-			$recipientsTable->changeColumn('id', [
+			$recipientsTable->modifyColumn('id', [
 				'type' => Type::getType(Types::BIGINT),
-				'length' => 20,
 			]);
 		}
 
@@ -135,9 +134,8 @@ class Version1130Date20220412111833 extends SimpleMigrationStep {
 
 		if (!$isSqlite) {
 			// Change primary column to bigint
-			$messagesTable->changeColumn('id', [
+			$messagesTable->modifyColumn('id', [
 				'type' => Type::getType(Types::BIGINT),
-				'length' => 20,
 			]);
 		}
 
@@ -177,6 +175,8 @@ class Version1130Date20220412111833 extends SimpleMigrationStep {
 	 * @param IOutput $output
 	 * @param Closure $schemaClosure The `\Closure` returns a `ISchemaWrapper`
 	 * @param array $options
+	 *
+	 * @return void
 	 */
 	#[\Override]
 	public function postSchemaChange(IOutput $output, \Closure $schemaClosure, array $options) {
