@@ -20,7 +20,6 @@ use OCP\AppFramework\Http\TemplateResponse;
 use OCP\Defaults;
 use OCP\IConfig;
 use OCP\IInitialStateService;
-use OCP\LDAP\ILDAPProvider;
 use OCP\Settings\ISettings;
 use OCP\TextProcessing\FreePromptTaskType;
 use OCP\TextProcessing\SummaryTaskType;
@@ -109,14 +108,6 @@ class AdminSettings implements ISettings {
 			$this->aiIntegrationsService->isLlmAvailable(SummaryTaskType::class)
 		);
 
-		$this->initialStateService->provideLazyInitialState(
-			Application::APP_ID,
-			'ldap_aliases_integration',
-			static function () {
-				return method_exists(ILDAPProvider::class, 'getMultiValueUserAttribute');
-			}
-		);
-
 		$this->initialStateService->provideInitialState(
 			Application::APP_ID,
 			'google_oauth_client_id',
